@@ -7,5 +7,5 @@ class LoggingPlugin(Plugin):
 
     def before_config(self):
         logging.config.fileConfig(
-            self.settings['logging:config'],
+            self.settings['paths:logging:config'],
             disable_existing_loggers=False)
